@@ -1,4 +1,4 @@
-import datetime
+# -*- coding: utf-8 -*-
 from . import util
 from .entry import Entry
 
@@ -15,7 +15,7 @@ def execute(args):
             entries[-1].datetime,
             entries[-1].name,
             entries[-1].is_current_entry)
-    entries[-1].datetime = datetime.datetime.today()
+    entries[-1].datetime = args.now
     util.write_entries(args.data_filename, entries)
     print("stretched " + str(old_entry))
     print("        → " + str(entries[-1]))
